summaryrefslogtreecommitdiffstats
path: root/kolf/canvasitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kolf/canvasitem.h')
-rw-r--r--kolf/canvasitem.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kolf/canvasitem.h b/kolf/canvasitem.h
index 6b789dfa..2b1bd1b4 100644
--- a/kolf/canvasitem.h
+++ b/kolf/canvasitem.h
@@ -6,7 +6,7 @@
#include "config.h"
class Ball;
-class KConfig;
+class TDEConfig;
class StateDB;
class KolfGame;
@@ -16,9 +16,9 @@ public:
CanvasItem() { game = 0; }
virtual ~CanvasItem() {}
/**
* load your settings from the KConfig, which represents a course.
*/
- virtual void load(KConfig *) {}
+ virtual void load(TDEConfig *) {}
/**
* load a point if you wish. Rarely necessary.
*/
@@ -38,7 +38,7 @@ public:
/**
* save your settings.
*/
- virtual void save(KConfig *cfg);
+ virtual void save(TDEConfig *cfg);
/**
* save a point if you wish. Rarely necessary.
*/
@@ -16,9 +16,9 @@ public:
virtual ~CanvasItem() {}
/**
- * load your settings from the KConfig, which represents a course.
+ * load your settings from the TDEConfig, which represents a course.
*/